@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2006 Sun Microsystems Inc.
+# Copyright 2006-2008 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -14,8 +14,8 @@
 #
 # You should have received a copy of the GNU Library General Public
 # License along with this library; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
+# Boston MA  02110-1301 USA.
 
 """Punctuation Verbosity settings.
 The Orca punctuation settings are broken up into 4 modes.
@@ -39,10 +39,10 @@ Each mode is defined below. The 4 bits of information listed here are:
     actual symbol or be inserted before the symbol.
 """
 
-__id__        = "$Id: punctuation_settings.py 2309 2007-04-23 14:04:01Z joanied $"
-__version__   = "$Revision: 2309 $"
-__date__      = "$Date: 2007-04-23 10:04:01 -0400 (Mon, 23 Apr 2007) $"
-__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
+__id__  = "$Id: punctuation_settings.py 4411 2009-01-08 15:09:09Z wwalker $"
+__version__   = "$Revision: 4411 $"
+__date__      = "$Date: 2009-01-08 15:09:09 +0000 (Thu, 08 Jan 2009) $"
+__copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import settings
@@ -90,7 +90,7 @@ cent                 =  u'\u00a2'
 pound                =  u'\u00a3'
 yen                  =  u'\u00a5'
 section              =  u'\u00a7'
-copyright            =  u'\u00a9'
+copyright_sign       =  u'\u00a9'
 not_sign             =  u'\u00ac'
 registered           =  u'\u00ae'
 degree               =  u'\u00b0'
@@ -105,8 +105,10 @@ divide               =  u'\u00f7'
 en_dash              =  u'\u2013'
 left_single_quote    =  u'\u2018'
 right_single_quote   =  u'\u2019'
+single_low_quote     =  u'\u201a'
 left_double_quote    =  u'\u201c'
 right_double_quote   =  u'\u201d'
+double_low_quote     =  u'\u201e'
 dagger               =  u'\u2020'
 double_dagger        =  u'\u2021'
 per_mille            =  u'\u2030'
@@ -157,7 +159,8 @@ punctuation[left_single_quote]  =  [ LEVEL_MOST, PUNCTUATION_REPLACE ]
 punctuation[left_double_quote]  =  [ LEVEL_MOST, PUNCTUATION_REPLACE ]
 punctuation[right_double_quote] =  [ LEVEL_MOST, PUNCTUATION_REPLACE ]
 punctuation[en_dash]            =  [ LEVEL_MOST, PUNCTUATION_REPLACE ]
-
+punctuation[double_low_quote]   =  [ LEVEL_MOST, PUNCTUATION_REPLACE ]
+punctuation[single_low_quote]   =  [ LEVEL_MOST, PUNCTUATION_REPLACE ]
 punctuation["#"] =  [ LEVEL_SOME, PUNCTUATION_REPLACE ]
 punctuation["$"] =  [ LEVEL_SOME, PUNCTUATION_REPLACE ]
 punctuation["%"] =  [ LEVEL_SOME, PUNCTUATION_REPLACE ]
@@ -173,7 +176,7 @@ punctuation[pound]              =  [ LEVEL_SOME, PUNCTUATION_REPLACE ]
 punctuation[yen]                =  [ LEVEL_SOME, PUNCTUATION_REPLACE ]
 punctuation[euro]               =  [ LEVEL_SOME, PUNCTUATION_REPLACE ]
 punctuation[not_sign]           =  [ LEVEL_SOME, PUNCTUATION_REPLACE ]
-punctuation[copyright]          =  [ LEVEL_SOME, PUNCTUATION_REPLACE ]
+punctuation[copyright_sign]     =  [ LEVEL_SOME, PUNCTUATION_REPLACE ]
 punctuation[registered]         =  [ LEVEL_SOME, PUNCTUATION_REPLACE ]
 punctuation[trademark]          =  [ LEVEL_SOME, PUNCTUATION_REPLACE ]
 punctuation[degree]             =  [ LEVEL_SOME, PUNCTUATION_REPLACE ]
