@@ -19,9 +19,9 @@
 
 """Custom script for Evolution."""
 
-__id__        = "$Id: script.py 4434 2009-01-19 16:08:35Z joanied $"
-__version__   = "$Revision: 4434 $"
-__date__      = "$Date: 2009-01-19 11:08:35 -0500 (Mon, 19 Jan 2009) $"
+__id__        = "$Id: script.py 4440 2009-01-20 22:06:12Z joanied $"
+__version__   = "$Revision: 4440 $"
+__date__      = "$Date: 2009-01-20 17:06:12 -0500 (Tue, 20 Jan 2009) $"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -522,10 +522,17 @@ class Script(default.Script):
 
         try:
             obj.queryHypertext()
+            ancestor = obj.parent.parent
         except:
             return False
         else:
-            return obj.getState().contains(pyatspi.STATE_MULTI_LINE)
+            # The accessible text objects in the header at the top
+            # of the message also have STATE_MULTI_LINE. But they
+            # are inside panels which are inside table cells; the
+            # body text is not. See bug #567428.
+            #
+            return (obj.getState().contains(pyatspi.STATE_MULTI_LINE) \
+                    and ancestor.getRole() != pyatspi.ROLE_TABLE_CELL)
 
     def presentMessageLine(self, obj, newLocusOfFocus):
         """Speak/braille the line at the current text caret offset.
